/* BdfServer_Commands - Copyright (c) 2011-2022 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package fr.exemole.bdfserver.commands.corpus;

import fr.exemole.bdfserver.api.BdfServer;
import fr.exemole.bdfserver.api.BdfServerEditor;
import fr.exemole.bdfserver.api.ui.UiComponents;
import fr.exemole.bdfserver.tools.instruction.AbstractBdfCommand;
import fr.exemole.bdfserver.tools.ui.UiUtils;
import fr.exemole.bdfserver.tools.ui.components.CommentUiBuilder;
import fr.exemole.bdfserver.tools.ui.components.UiComponentUtils;
import net.fichotheque.corpus.Corpus;
import net.mapeadores.util.logging.ErrorMessageException;
import net.mapeadores.util.request.RequestMap;


/**
 *
 * @author Vincent Calame
 */
public class CommentCreationCommand extends AbstractBdfCommand {

    public final static String COMMANDNAME = "CommentCreation";
    public final static String COMMANDKEY = "_ CRP-15";
    private Corpus corpus;
    private CommentUiBuilder commentUiBuilder;

    public CommentCreationCommand(BdfServer bdfServer, RequestMap requestMap) {
        super(bdfServer, requestMap);
    }

    @Override
    public boolean needSynchronisation() {
        return true;
    }

    @Override
    protected void doCommand() {
        putResultObject(CORPUS_OBJ, corpus);
        BdfServerEditor bdfServerEditor = bdfServer.getBdfServerEditor();
        UiComponents uiComponents = bdfServer.getUiManager().getMainUiComponents(corpus);
        String name = getCommentName(uiComponents);
        commentUiBuilder.setName(name);
        boolean done = bdfServerEditor.putComponentUi(uiComponents, commentUiBuilder.toCommentUi());
        if (done) {
            bdfServerEditor.saveChanges();
            setDone("_ done.corpus.commentcreation", name);
        }
    }

    @Override
    protected void checkParameters() throws ErrorMessageException {
        corpus = getMandatoryCorpus();
        checkSubsetAdmin(corpus);
        commentUiBuilder = CommentUiBuilder.init(bdfServer.getUiManager().getTrustedHtmlFactory(), null)
                .setLocation(CommentChangeCommand.getLocation(requestMap, CommentChangeCommand.LOCATION_PARAMNAME));
        CommentChangeCommand.putHtmlString(commentUiBuilder, requestMap, CommentChangeCommand.COMMENT_PREFIX);
    }

    private String getCommentName(UiComponents uiComponents) {
        int number = 1 + UiComponentUtils.getCommentUiList(uiComponents).size();
        String name = null;
        while (true) {
            name = "c" + String.valueOf(number);
            if (!uiComponents.contains(UiUtils.toComponentUiName(name))) {
                break;
            } else {
                number++;
            }
        }
        return name;
    }

}
