/* FichothequeLib_Tools - Copyright (c) 2011-2022 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package net.fichotheque.tools.extraction;

import net.fichotheque.extraction.LinkAnalyser;
import net.fichotheque.extraction.SyntaxResolver;
import net.fichotheque.extraction.def.AddendaExtractDef;
import net.fichotheque.extraction.def.AlbumExtractDef;
import net.fichotheque.extraction.def.CorpusExtractDef;
import net.fichotheque.extraction.def.ThesaurusExtractDef;
import net.fichotheque.extraction.run.AddendaExtractor;
import net.fichotheque.extraction.run.AlbumExtractor;
import net.fichotheque.extraction.run.CorpusExtractor;
import net.fichotheque.extraction.run.ExtractorProvider;
import net.fichotheque.extraction.run.ThesaurusExtractor;
import net.fichotheque.tools.extraction.syntaxes.AttributeResolver;
import net.fichotheque.tools.extraction.syntaxes.FicheblockResolver;
import net.fichotheque.tools.extraction.syntaxes.JavaResolver;
import net.fichotheque.tools.extraction.syntaxes.PathResolver;
import net.fichotheque.tools.extraction.syntaxes.PropertyResolver;


/**
 *
 * @author Vincent Calame
 */
public final class ExtractionContextUtils {

    public final static ExtractorProvider DEFAULT_EXTRACTORPROVIDER = new DefaultExtractorProvider();
    public final static LinkAnalyser DEFAULT_LINKANALYSER = new DefaultLinkAnalyser();
    public final static SyntaxResolver DEFAULT_SYNTAXRESOLVER = new DefaultSyntaxResolver();


    private ExtractionContextUtils() {
    }


    private static class DefaultLinkAnalyser implements LinkAnalyser {

        private DefaultLinkAnalyser() {
        }

        @Override
        public boolean isExternalLink(String href) {
            if (href == null) {
                return false;
            }
            return (href.indexOf("://") > 0);
        }

    }


    private static class DefaultExtractorProvider implements ExtractorProvider {

        private DefaultExtractorProvider() {
        }

        @Override
        public AddendaExtractor getAddendaExtractor(AddendaExtractDef addendaExtractDef) {
            return new AddendaExtractorImpl(addendaExtractDef);
        }

        @Override
        public AlbumExtractor getAlbumExtractor(AlbumExtractDef albumExtractDef) {
            return new AlbumExtractorImpl(albumExtractDef);
        }

        @Override
        public CorpusExtractor getCorpusExtractor(CorpusExtractDef corpusExtractDef) {
            return new CorpusExtractorImpl(corpusExtractDef);
        }

        @Override
        public ThesaurusExtractor getThesaurusExtractor(ThesaurusExtractDef thesaurusExtractDef) {
            return new ThesaurusExtractorImpl(thesaurusExtractDef);
        }

    }


    private static class DefaultSyntaxResolver implements SyntaxResolver {


        private DefaultSyntaxResolver() {

        }

        @Override
        public String toCData(String syntaxName, String sValue) {
            switch (syntaxName) {
                case "attribute":
                    return AttributeResolver.resolve(sValue);
                case "ficheblock":
                    return FicheblockResolver.resolve(sValue);
                case "java-class":
                    return JavaResolver.resolve(sValue, JavaResolver.CLASS);
                case "java-interface":
                    return JavaResolver.resolve(sValue, JavaResolver.INTERFACE);
                case "path":
                    return PathResolver.resolve(sValue, -1);
                case "property":
                    return PropertyResolver.resolve(sValue);
                default:
                    return "";
            }
        }

    }


}
