/* UtilLib - Copyright (c) 2012-2018 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package net.mapeadores.util.logging;

import java.util.List;
import net.mapeadores.util.localisation.Message;


/**
 *
 * @author Vincent Calame
 */
public class SimpleMessageHandler implements MessageHandler {

    private final CategorizedMessageBuffer buffer = new CategorizedMessageBuffer();

    public SimpleMessageHandler() {
    }

    @Override
    public void addMessage(String category, Message message) {
        buffer.add(category, message);
    }

    public boolean hasMessage() {
        return (!buffer.isEmpty());
    }

    public List<CategorizedMessageEntry> toList() {
        return buffer.toEntryList();
    }

    public List<Message> filter(String category) {
        return buffer.toMessageList(category);
    }

    public List<Message> filterWarning() {
        return buffer.toMessageList("warning.");
    }

    public List<Message> filterSevere() {
        return buffer.toMessageList("severe.");
    }

    @Override
    public String toString() {
        StringBuilder buf = new StringBuilder();
        List<CategorizedMessageEntry> list = buffer.toEntryList();
        for (CategorizedMessageEntry entry : list) {
            Message message = entry.getMessage();
            if (buf.length() > 0) {
                buf.append("\n");
            }
            buf.append(message.getMessageKey());
            Object[] values = message.getMessageValues();
            int length = values.length;
            if (length > 0) {
                for (int i = 0; i < length; i++) {
                    if (i > 0) {
                        buf.append(" / ");
                    } else {
                        buf.append(": ");
                    }
                    buf.append(values[i].toString());
                }
            }
        }
        return buf.toString();
    }

}
