/* UtilLib_Servlet - Copyright (c) 2009-2020 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package net.mapeadores.util.servlets;

import net.mapeadores.util.logging.CommandMessage;
import net.mapeadores.util.logging.LogUtils;


/**
 *
 * @author Vincent Calame
 */
public class HttpAccessException extends RuntimeException {

    public final static int BAD_REQUEST = 400;
    public final static int NOT_FOUND = 404;
    public final static int FORBIDDEN_ACCESS = 403;
    public final static int INTERNAL_ERROR = 500;
    private final int httpType;
    private final String message;
    private final CommandMessage commandMessage;

    public HttpAccessException(int httpType) {
        this.httpType = httpType;
        this.message = null;
        this.commandMessage = null;
    }

    public HttpAccessException(int httpType, String message) {
        this.httpType = httpType;
        this.message = message;
        this.commandMessage = null;
    }

    public HttpAccessException(int httpType, CommandMessage commandMessage) {
        this.httpType = httpType;
        this.message = commandMessage.getMessageKey();
        this.commandMessage = commandMessage;
    }

    public HttpAccessException(int httpType, String message, CommandMessage commandMessage) {
        this.httpType = httpType;
        this.message = message;
        this.commandMessage = commandMessage;
    }

    public HttpAccessException(String messageKey, Object... messageValues) {
        this.httpType = HttpAccessException.BAD_REQUEST;
        this.message = messageKey;
        this.commandMessage = LogUtils.error(messageKey, messageValues);
    }


    public int getHttpType() {
        return httpType;
    }

    @Override
    public String getMessage() {
        return message;
    }

    public CommandMessage getCommandMessage() {
        return commandMessage;
    }

}
